==> ejc-proequipmentp-impl-3.0.0-20220705.072229-157-sources.jar: com/ejianc/business/asset/bean/HandleDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备处置子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_handle_detail")
public class HandleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="handle_id")
    private Long handleId; // 主表d
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 材料分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 材料分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 材料分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 材料id
    @TableField(value="equipment_code")
    private String equipmentCode; // 材料编码
    @TableField(value="equipment_name")
    private String equipmentName; // 材料名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="use_company_id")
    private Integer useCompanyId; // 使用单位id
    @TableField(value="use_company")
    private String useCompany; // 使用单位
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 出厂日期
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_depreciation_mny")
    private BigDecimal lastDepreciationMny; // 累计折旧金额（无税）
    @TableField(value="last_depreciation_tax_mny")
    private BigDecimal lastDepreciationTaxMny; // 累计折旧金额（含税）
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额(无税)
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额(含税)
    @TableField(value="handle_diff_mny")
    private BigDecimal handleDiffMny; // 处置差额（无税）
    @TableField(value="handle_diff_tax_mny")
    private BigDecimal handleDiffTaxMny; // 处置差额（含税）
    
    
    

    public Long getHandleId() {
        return handleId;
    }

    public void setHandleId(Long handleId) {
        this.handleId = handleId;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Integer getUseCompanyId() {
        return useCompanyId;
    }

    public void setUseCompanyId(Integer useCompanyId) {
        this.useCompanyId = useCompanyId;
    }
    public String getUseCompany() {
        return useCompany;
    }

    public void setUseCompany(String useCompany) {
        this.useCompany = useCompany;
    }
    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }
    public BigDecimal getLastDepreciationMny() {
        return lastDepreciationMny;
    }

    public void setLastDepreciationMny(BigDecimal lastDepreciationMny) {
        this.lastDepreciationMny = lastDepreciationMny;
    }
    public BigDecimal getLastDepreciationTaxMny() {
        return lastDepreciationTaxMny;
    }

    public void setLastDepreciationTaxMny(BigDecimal lastDepreciationTaxMny) {
        this.lastDepreciationTaxMny = lastDepreciationTaxMny;
    }
    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }
    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
    public BigDecimal getHandleDiffMny() {
        return handleDiffMny;
    }

    public void setHandleDiffMny(BigDecimal handleDiffMny) {
        this.handleDiffMny = handleDiffMny;
    }
    public BigDecimal getHandleDiffTaxMny() {
        return handleDiffTaxMny;
    }

    public void setHandleDiffTaxMny(BigDecimal handleDiffTaxMny) {
        this.handleDiffTaxMny = handleDiffTaxMny;
    }
    
}

==> ejc-proequipmentp-impl-3.0.0-20220707.121439-169-sources.jar: com/ejianc/business/asset/bean/HandleDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备处置子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_handle_detail")
public class HandleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="handle_id")
    private Long handleId; // 主表d
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 材料分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 材料分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 材料分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 材料id
    @TableField(value="equipment_code")
    private String equipmentCode; // 材料编码
    @TableField(value="equipment_name")
    private String equipmentName; // 材料名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="use_company_id")
    private Integer useCompanyId; // 使用单位id
    @TableField(value="use_company")
    private String useCompany; // 使用单位
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 出厂日期
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_amortize_mny")
    private BigDecimal lastAmortizeMny; // 累计摊销金额(无税)
    @TableField(value="last_amortize_tax_mny")
    private BigDecimal lastAmortizeTaxMny; // 累计摊销金额(含税)
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额(无税)
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额(含税)
    @TableField(value="handle_diff_mny")
    private BigDecimal handleDiffMny; // 处置差额（无税）
    @TableField(value="handle_diff_tax_mny")
    private BigDecimal handleDiffTaxMny; // 处置差额（含税）
    
    
    

    public Long getHandleId() {
        return handleId;
    }

    public void setHandleId(Long handleId) {
        this.handleId = handleId;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Integer getUseCompanyId() {
        return useCompanyId;
    }

    public void setUseCompanyId(Integer useCompanyId) {
        this.useCompanyId = useCompanyId;
    }
    public String getUseCompany() {
        return useCompany;
    }

    public void setUseCompany(String useCompany) {
        this.useCompany = useCompany;
    }
    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }

    public BigDecimal getLastAmortizeMny() {
        return lastAmortizeMny;
    }

    public void setLastAmortizeMny(BigDecimal lastAmortizeMny) {
        this.lastAmortizeMny = lastAmortizeMny;
    }

    public BigDecimal getLastAmortizeTaxMny() {
        return lastAmortizeTaxMny;
    }

    public void setLastAmortizeTaxMny(BigDecimal lastAmortizeTaxMny) {
        this.lastAmortizeTaxMny = lastAmortizeTaxMny;
    }

    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }
    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
    public BigDecimal getHandleDiffMny() {
        return handleDiffMny;
    }

    public void setHandleDiffMny(BigDecimal handleDiffMny) {
        this.handleDiffMny = handleDiffMny;
    }
    public BigDecimal getHandleDiffTaxMny() {
        return handleDiffTaxMny;
    }

    public void setHandleDiffTaxMny(BigDecimal handleDiffTaxMny) {
        this.handleDiffTaxMny = handleDiffTaxMny;
    }
    
}
